@@ -13,7 +13,6 @@ import IPython
 from IPython import get_ipython
 from IPython.core.error import UsageError
 
-# from ads.environment import ads_inspect
 import matplotlib.font_manager  # causes matplotlib to regenerate its fonts
 import json
 
@@ -58,14 +57,13 @@ def set_auth(auth="api_key", profile="DEFAULT"):
         resource_principal_mode = True
 
 
-try:
-    from ads.environment import ml_runtime
+def getLogger(name="ads"):
+    logger = logging.getLogger(name)
+    logger.setLevel(logging.WARNING)
+    return logger
 
-    # import ocifs
-except ImportError as e:
-    raise ImportError(str(e) + "\n\n" + "ads is not installed")
 
-logger = logging.getLogger(__name__)
+logger = getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
 # All warnings are logged by default
@@ -140,9 +138,9 @@ def _set_test_mode(mode=False):
 
 def hello():
     """
-    Imports Dask, Pandas, sets the documentation mode, and prints a fancy "Hello".
+    Imports Pandas, sets the documentation mode, and prints a fancy "Hello".
     """
-    import dask, pandas
+    import pandas
 
     global documentation_mode
     global debug_mode
@@ -199,7 +197,3 @@ else:
     plt.switch_backend("agg")
 
 
-if documentation_mode:
-    logger.info(
-        "Use `ads.environment.ads_inspect.check_ads_env()` to determine if the version of the libraries in the current environment conflicts with ADS dependencies."
-    )
