@@ -8,8 +8,6 @@ from __future__ import print_function, absolute_import, division
 
 import copy
 
-import dask.dataframe as dd
-import logging
 from ads.common.model import ADSModel
 from ads.common import logger
 from ads.dataset import helper
@@ -23,7 +21,6 @@ from ads.dataset.classification_dataset import (
 from ads.dataset.regression_dataset import RegressionDataset
 
 from ads.dataset.pipeline import TransformerPipeline
-from ads.environment import ml_runtime
 from ads.type_discovery.type_discovery_driver import TypeDiscoveryDriver
 from ads.type_discovery.typed_feature import (
     ContinuousTypedFeature,
@@ -83,7 +80,12 @@ def get_ml_task_type(X, y, classes):
 
 class AutoML:
     def __init__(
-        self, training_data, validation_data=None, provider=None, baseline="dummy"
+        self,
+        training_data,
+        validation_data=None,
+        provider=None,
+        baseline="dummy",
+        client=None,
     ):
         """
         Creates an Automatic machine learning object.
@@ -100,6 +102,8 @@ class AutoML:
             If Object, than whatever estimator is provided will be used.
               This estimator must include a part of its pipeline which does preprocessing
               to handle categorical data
+        client: Dask Client to use (optional)
+
 
 
         Examples
@@ -125,33 +129,34 @@ class AutoML:
 
         X = (
             training_data.X.compute()
-            if isinstance(training_data.X, dd.DataFrame)
+            if utils._is_dask_dataframe(training_data.X)
             else training_data.X
         )
         y = (
             training_data.y.compute()
-            if isinstance(training_data.y, dd.Series)
+            if utils._is_dask_dataframe(training_data.y)
+            or utils._is_dask_series(training_data.y)
             else training_data.y
         )
-
         self.X_shape = X.shape
 
         X_valid = None
         y_valid = None
         if validation_data is not None:
             X_valid = (
-                validation_data.X.compute()
-                if isinstance(validation_data.X, dd.DataFrame)
-                else validation_data.X
+                training_data.X.compute()
+                if utils._is_dask_dataframe(training_data.X)
+                else training_data.X
             )
             y_valid = (
-                validation_data.y.compute()
-                if isinstance(validation_data.y, dd.Series)
-                else validation_data.y
+                training_data.y.compute()
+                if utils._is_dask_dataframe(training_data.y)
+                or utils._is_dask_series(training_data.y)
+                else training_data.y
             )
         self.target_name = y.name
         self.feature_names = X.columns.values
-        self.client = ml_runtime.compute_accelerator()
+        self.client = client
         class_names = y.unique()
 
         if training_data.dataset_type in dataset_task_map:
@@ -250,9 +255,7 @@ class AutoML:
         """
 
         time_budgeted = "time_budget" in kwargs
-        avail_n_cores = max(
-            utils.get_compute_accelerator_ncores(), utils.get_cpu_count()
-        )
+        avail_n_cores = utils.get_cpu_count()
 
         warn_params = [
             (10 ** 5, 4, "VM.Standard.E2.4"),
