@@ -987,7 +987,7 @@ class ModelCatalog:
         display_name=None,
         description=None,
         freeform_tags=None,
-        defined_tags=None
+        defined_tags=None,
     ):
         """
         Uploads the model artifact to cloud storage.
@@ -1044,8 +1044,7 @@ class ModelCatalog:
                 if model_artifact.schema_output is not None
                 else '{"schema": []}',
                 freeform_tags=freeform_tags,
-                defined_tags=defined_tags
-
+                defined_tags=defined_tags,
             )
 
             model = self.ds_client.create_model(create_model_details)
