@@ -5,7 +5,7 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import numpy as np
-import dask.dataframe as dd
+from ads.common.utils import _is_dask_dataframe, _is_dask_series
 
 
 class ADSData(object):
@@ -32,9 +32,9 @@ class ADSData(object):
         dataset_type: ADSDataset optional
             When this value is available, would be used to evaluate the ads task
             type
-        kwargs: additional keyword arguments that would be passed to underlying dask read API
-            See http://docs.dask.org/en/latest/dataframe-api.html#create-dataframes for the list of kwargs supported
-            based on the format of the dataset
+        kwargs: Additional keyword arguments that would be passed to the underlying Pandas
+            read API.
+
         """
         self.X = X
         self.y = y
@@ -58,9 +58,8 @@ class ADSData(object):
         dataset_type: ADSDataset optional
             When this value is available, would be used to evaluate the ads task
             type
-        kwargs: additional keyword arguments that would be passed to underlying dask read API
-            See http://docs.dask.org/en/latest/dataframe-api.html#create-dataframes for the list of kwargs supported
-            based on the format of the dataset
+        kwargs: Additional keyword arguments that would be passed to the underlying Pandas
+            read API.
 
         Returns
         -------
@@ -75,9 +74,9 @@ class ADSData(object):
         """
         if X is None or y is None:
             raise ValueError("Both X and y are required.")
-        if isinstance(X, dd.core.DataFrame):
+        if _is_dask_dataframe(X):
             X = X.compute()
-        if isinstance(y, dd.core.Series):
+        if _is_dask_series(y):
             y = y.compute()
         if dataset_type is None:
             dataset_type = type(X)
