@@ -245,7 +245,7 @@ class ADSModel(object):
         else:
             assert hasattr(self.est, "score"), (
                 f"Could not find a score function for estimator of type: "
-                f"{self._underlying_model}. Please pass in your desired scoring "
+                f"{self._underlying_model}. Pass in your desired scoring "
                 f"function to score_fn "
             )
             if self.client is not None and self.booster is not None:
@@ -383,6 +383,7 @@ class ADSModel(object):
         data_science_env=False,
         ignore_deployment_error=False,
         use_case_type=None,
+        inference_python_version=None,
     ):
         """
         Prepare model artifact directory to be published to model catalog
@@ -395,10 +396,10 @@ class ADSModel(object):
             Note: This format is preferable to X_sample and y_sample.
             A sample of the test data that will be provided to predict() API of scoring script
             Used to generate schema_input.json and schema_output.json which defines the input and output formats
-        X_sample : Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
+        X_sample : pandas.DataFrame
             A sample of input data that will be provided to predict() API of scoring script
             Used to generate schema.json which defines the input formats
-        y_sample : Union[pandas.Series, dask.dataframe.core.Series]
+        y_sample : pandas.Series
             A sample of output data that is expected to be returned by predict() API of scoring script,
             corresponding to X_sample
             Used to generate schema_output.json which defines the output formats
@@ -415,7 +416,11 @@ class ADSModel(object):
         ignore_deployment_error : bool, default: False
             If set to True, the prepare will ignore all the errors that may impact model deployment
         use_case_type: str
-            The use case type of the model
+            The use case type of the model. Use it through UserCaseType class or string provided in UseCaseType. For
+            example, use_case_type=UseCaseType.BINARY_CLASSIFICATION or use_case_type="binary_classification". Check
+            with UseCaseType class to see all supported types.
+        inference_python_version: str, default:None.
+            If provided will be added to the generated runtime yaml
 
         Returns
         -------
@@ -516,6 +521,7 @@ class ADSModel(object):
                 fn_artifact_files_included=fn_artifact_files_included,
                 fn_name=fn_name,
                 force_overwrite=force_overwrite,
+                inference_python_version=inference_python_version,
                 **model_kwargs,
             )
             try:
