@@ -109,7 +109,7 @@ class ChangesNotCommitted(Exception):
     def __init__(self, path):
         msg = f"""
             File(s) at {path} are either dirty or untracked.
-            Please commit changes and then save the model, or set `ignore_pending_changes=True`.
+            Commit changes and then save the model, or set `ignore_pending_changes=True`.
         """
         super().__init__(msg)
 
@@ -438,7 +438,7 @@ class ModelArtifact(Introspectable):
             )
         inference_info = ns.InferenceCondaEnv()
         if not self.inference_conda_env:
-            message = f"We give you the option to specify a different inference conda environment for model deployment purposes. By default it is assumed to be the same as the conda environment used to train the model. If you wish to specify a different environment for inference purposes, please assign the path of a published or data science conda environment to the optional parameter `inference_conda_env`. "
+            message = f"We give you the option to specify a different inference conda environment for model deployment purposes. By default it is assumed to be the same as the conda environment used to train the model. If you wish to specify a different environment for inference purposes, assign the path of a published or data science conda environment to the optional parameter `inference_conda_env`. "
             if (
                 training_env_info.TRAINING_ENV_TYPE
                 and training_env_info.TRAINING_ENV_PATH
@@ -469,7 +469,8 @@ class ModelArtifact(Introspectable):
                     if not self.inference_python_version:
                         if not training_env_info.TRAINING_PYTHON_VERSION:
                             raise Exception(
-                                "Python version is not specified, please pass in python version when preparing model."
+                                "The Python version is not specified."
+                                "Pass in the python version when a preparing model."
                             )
                         else:
                             logger.warning(
@@ -964,7 +965,7 @@ class ModelArtifact(Introspectable):
             )
         else:
             raise FileNotFoundError(
-                "Could not find requirements file. Please install necessary libraries and "
+                "Could not find requirements file. Install necessary libraries and "
                 "re-construct the model artifact with install_libs=False"
             )
 
