@@ -34,5 +34,7 @@ class ObjectStorageDetails:
     def path(self):
         """Full object storage path of this file."""
         return os.path.join(
-            "oci://", self.bucket + "@" + self.namespace, self.filepath.lstrip("/")
+            "oci://",
+            self.bucket + "@" + self.namespace,
+            self.filepath.lstrip("/") if self.filepath else "",
         )
