@@ -99,7 +99,7 @@ class DataFlow:
         )
         if not self.region:
             logger.warning(
-                "Region information not found from oci config file. Please set region in the OCI config file"
+                "Region information not found from oci config file. Set region in the OCI config file"
             )
         try:
             self.namespace = self.object_storage_client.get_namespace().data
@@ -670,7 +670,7 @@ class DataFlow:
         if self._check_object_exist(object_name, bucket_name):
             if not overwrite:
                 raise ValueError(
-                    "You have a file with the same key in your bucket on object storage. Please rename your file or set overwrite option to True."
+                    "You have a file with the same key in your bucket on object storage. Rename your file or set overwrite option to True."
                 )
             else:
                 logger.warning(
@@ -1816,7 +1816,7 @@ class DataFlowLog:
         if self._local_path is None:
             logger.warning(
                 "The log file is not stored in local directory. "
-                "Please call the save() method to save the log file to local first.",
+                "Call the save() method to save the log file to local first.",
             )
 
         return self._local_path
