@@ -9,11 +9,11 @@ from __future__ import print_function, absolute_import
 import numpy as np
 import pandas as pd
 
-from ads.common import utils, logger
+from ads.common import logger
 from ads.dataset.exception import ValidationError
 from collections import defaultdict, Counter
 from itertools import product, combinations
-from time import sleep
+from typing import Tuple
 
 
 def _cat_vs_cat(df: pd.core.frame.DataFrame, categorical_columns: list) -> pd.DataFrame:
@@ -91,7 +91,9 @@ def _correlation_ratio(cat: np.ndarray, cts: np.ndarray):
     return np.sqrt(ratio)
 
 
-def _count_occurrence(cat1: np.ndarray, cat2: np.ndarray) -> (np.ndarray, int, int):
+def _count_occurrence(
+    cat1: np.ndarray, cat2: np.ndarray
+) -> Tuple[np.ndarray, int, int]:
     """
     calc the contingency table of two arrays
     """
@@ -146,7 +148,7 @@ def _cramers_v(cat1: np.ndarray, cat2: np.ndarray) -> float:
 
 def _get_columns_by_type(
     feature_types_df: pd.DataFrame, threshold: float = 0.8
-) -> (list, list, list):
+) -> Tuple[list, list, list]:
     """
     return the categorical columns, continuous columns and columns of other types
     """
