@@ -8,13 +8,18 @@ import operator
 import types
 import uuid
 from functools import partial
-
-import dask
-from dask.dataframe.accessor import Accessor
-from dask.utils import OperatorMethodMixin
 from sklearn.preprocessing import FunctionTransformer
+from ads.common.deprecate import deprecated
+
+try:
+    import dask
+    from dask.dataframe.accessor import Accessor
+    from dask.utils import OperatorMethodMixin
+except ImportError as e:
+    raise ModuleNotFoundError("Install dask to use the Dask Series class.") from e
 
 
+@deprecated("2.5.2")
 class DaskSeries(dask.dataframe.core.Series, OperatorMethodMixin):
     """
     A DaskSeries object.
@@ -144,6 +149,7 @@ for op in [
     DaskSeries._bind_operator(op)
 
 
+@deprecated("2.5.2")
 class DaskSeriesAccessor:
     """
     A DaskSeriesAccessor object.
