@@ -7,9 +7,7 @@
 from __future__ import absolute_import, print_function
 
 import abc
-import html
 import importlib
-import uuid
 from collections import defaultdict
 from numbers import Number
 from typing import Union
@@ -30,7 +28,7 @@ from ads.dataset.recommendation import Recommendation
 from ads.dataset.recommendation_transformer import RecommendationTransformer
 from ads.dataset.target import TargetVariable
 from ads.type_discovery.typed_feature import DateTimeTypedFeature
-from dask_ml.model_selection import train_test_split
+from sklearn.model_selection import train_test_split
 from IPython.display import HTML, display
 from pandas.io.formats.printing import pprint_thing
 from sklearn.preprocessing import FunctionTransformer
@@ -44,7 +42,7 @@ class ADSDatasetWithTarget(ADSDataset):
 
     def __init__(
         self,
-        ddf,
+        df,
         sampled_df,
         target,
         target_type,
@@ -67,7 +65,7 @@ class ADSDatasetWithTarget(ADSDataset):
             cols.insert(0, cols.pop(cols.index(target)))
             ADSDataset.__init__(
                 self,
-                ddf,
+                df,
                 sampled_df[[*cols]],
                 shape,
                 name=name,
@@ -112,18 +110,18 @@ class ADSDatasetWithTarget(ADSDataset):
         # has na values
         #
 
-        if self.ddf[target].isna().sum().compute():
+        if self.df[target].isna().sum():
             #
             # remove rows for which the target is null
             #
-            self.ddf = self.ddf.dropna(subset=[target])
+            self.df = self.df.dropna(subset=[target])
 
             #
             # we cannot simply drop null values from the sampled_df after a change
-            # to the ddf - we must rebuild the sample from the new ddf
+            # to the df - we must rebuild the sample from the new df
             #
             self.sampled_df = helper.generate_sample(
-                self.ddf,
+                self.df,
                 sampled_df.shape[0],
                 helper.DatasetDefaults.sampling_confidence_level,
                 helper.DatasetDefaults.sampling_confidence_interval,
@@ -186,7 +184,7 @@ class ADSDatasetWithTarget(ADSDataset):
         """
         tf = self._get_best_features_transformer(score_func=score_func, k=k)
         return self._build_new_dataset(
-            tf[1].transform(self.ddf), tf[1].transform(self.sampled_df), transformers=tf
+            tf[1].transform(self.df), tf[1].transform(self.sampled_df), transformers=tf
         )
 
     def auto_transform(
@@ -251,14 +249,14 @@ class ADSDatasetWithTarget(ADSDataset):
         if correlation_threshold > 1 or correlation_threshold < 0:
             raise AssertionError("correlation_threshold has to be between 0 and 1.")
         with utils.get_progress_bar(5) as progress:
-            ddf, sampled_df, transformer_pipeline = self._transform(
+            df, sampled_df, transformer_pipeline = self._transform(
                 progress=progress,
                 correlation_threshold=correlation_threshold,
                 frac=sample_size,
                 correlation_methods=correlation_methods,
             )
             return self._build_new_dataset(
-                ddf,
+                df,
                 sampled_df=sampled_df,
                 transformers=transformer_pipeline.steps,
                 progress=progress,
@@ -271,9 +269,7 @@ class ADSDatasetWithTarget(ADSDataset):
 
         helper.visualize_transformation(
             self.transformer_pipeline,
-            text="- partition(s): {}\\l- rows: {}\\l- columns: {}\\l".format(
-                self.ddf.npartitions, *self.shape
-            ),
+            text="- rows: {}\\l- columns: {}\\l".format(*self.shape),
         )
 
     def _suggested_code(self, action, recommendation_type, variable):
@@ -287,7 +283,7 @@ class ADSDatasetWithTarget(ADSDataset):
             return ".down_sample()"
         if action == "Up-sample":
             if importlib.util.find_spec("imblearn") is None:
-                return ".up_sample(sampler='default') \\n Please `pip install imbalanced-learn` to use default up-sampler."
+                return ".up_sample(sampler='default') \\n `pip install imbalanced-learn` to use default up-sampler."
             else:
                 return ".up_sample(sampler='default')"
         if recommendation_type == "positive_class" and action != "Do nothing":
@@ -638,8 +634,8 @@ class ADSDatasetWithTarget(ADSDataset):
         train, test = ds.train_test_split()
         """
         X_train, X_test, y_train, y_test = train_test_split(
-            self.ddf.drop(self.target.name, axis=1),
-            self.ddf[self.target.name],
+            self.df.drop(self.target.name, axis=1),
+            self.df[self.target.name],
             test_size=test_size,
             train_size=1 - test_size,
             random_state=random_state,
@@ -746,12 +742,12 @@ class ADSDatasetWithTarget(ADSDataset):
             ] + transformer_pipeline.steps
         sampled_df = self.sampled_df.copy()
         self.recommendation_transformer = None
-        ddf = self.ddf.copy()
+        df = self.df.copy()
         for step in transformer_pipeline.steps:
             progress.update("Applying transformation for %s" % step[0])
             sampled_df = step[1].fit_transform(sampled_df)
-            ddf = step[1].transform(ddf, progress=progress, fit_transform=True)
-        return ddf, sampled_df, transformer_pipeline
+            df = step[1].transform(df, progress=progress, fit_transform=True)
+        return df, sampled_df, transformer_pipeline
 
     def _get_best_features(self, score_func=None, k=12):
         if isinstance(self.target.type, DateTimeTypedFeature):
