@@ -8,25 +8,14 @@ from __future__ import print_function, absolute_import
 
 import os
 import re
-import shutil
+import warnings
 import oci
-
 import datetime
-
-mindate = datetime.date(datetime.MINYEAR, 1, 1)
-
-import dask
 import pandas as pd
-import six  # python version compatibility layer
-from IPython import get_ipython
 from IPython.core.display import display
 from fsspec.utils import infer_storage_options
-from ipywidgets import HTML
-import io
-import numpy as np
 import inspect
 import fsspec
-from dask import dataframe as dd
 
 from ads.common import utils
 from ads.common.utils import is_same_class
@@ -43,14 +32,11 @@ from ads.dataset.helper import (
     get_feature_type,
     is_text_data,
     generate_sample,
-    map_types,
     DatasetDefaults,
     ElaboratedPath,
     DatasetLoadException,
-    _num_partitions_for_dataframe,
 )
 from ads.dataset.regression_dataset import RegressionDataset
-from ads.environment import ml_runtime as runtime
 from ads.type_discovery.type_discovery_driver import TypeDiscoveryDriver
 from ads.type_discovery.typed_feature import (
     ContinuousTypedFeature,
@@ -61,11 +47,12 @@ from ads.type_discovery.typed_feature import (
     DocumentTypedFeature,
 )
 from ads.type_discovery.typed_feature import TypedFeature
-from typing import Callable, Tuple, Optional, Any
+from typing import Callable, Tuple
 from ocifs import OCIFileSystem
 
 default_snapshots_dir = None
 default_storage_options = None
+mindate = datetime.date(datetime.MINYEAR, 1, 1)
 
 
 class DatasetFactory:
@@ -92,7 +79,7 @@ class DatasetFactory:
 
         Parameters
         ----------
-        source: Union[str, pandas.DataFrame, dask.dataframe.core.DataFrame, h2o.DataFrame, pyspark.sql.dataframe.DataFrame]
+        source: Union[str, pandas.DataFrame, h2o.DataFrame, pyspark.sql.dataframe.DataFrame]
             If str, URI for the dataset. The dataset could be read from local or network file system, hdfs, s3, gcs and optionally pyspark in pyspark
             conda env
         target: str, optional
@@ -110,7 +97,7 @@ class DatasetFactory:
         name: str, optional default: ""
         description: str, optional default: ""
             Text describing the dataset
-        npartitions: int, optional
+        npartitions: int, deprecated
             Number of partitions to split the data
             By default this is set to the max number of cores supported by the backend compute accelerator
         type_discovery: bool, default: True
@@ -138,8 +125,7 @@ class DatasetFactory:
             Parameters passed on to the backend filesystem class.
         sep: str
             Delimiting character for parsing the input file.
-        kwargs: additional keyword arguments that would be passed to underlying dask read API
-            See http://docs.dask.org/en/latest/dataframe-api.html#create-dataframes for the list of kwargs supported
+        kwargs: additional keyword arguments that would be passed to underlying dataframe read API
             based on the format of the dataset
 
         Returns
@@ -164,11 +150,16 @@ class DatasetFactory:
         >>> ds = DatasetFactory.open("/path/to/data.parquet", engine='pyarrow', types={"col1": "ordinal", \
                     "col2": "categorical", "col3" : "continuous", "col4" : "float64"})
 
-        >>> ds = DatasetFactory.open(df, target="class", sample_max_rows=5000, positive_class="yes", npartitions=2)
+        >>> ds = DatasetFactory.open(df, target="class", sample_max_rows=5000, positive_class="yes")
 
         >>> ds = DatasetFactory.open("s3://path/to/data.json.gz", format="json", compression="gzip", orient="records")
         """
-
+        if npartitions:
+            warnings.warn(
+                "Variable `npartitions` is deprecated and will not be used",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         if (
             "storage_options" not in kwargs
             and type(source) is str
@@ -188,24 +179,18 @@ class DatasetFactory:
             )
             df = load_dataset(path=path, reader_fn=reader_fn, **kwargs)
             name = path.name
-        elif isinstance(source, pd.DataFrame) or isinstance(source, dd.DataFrame):
+        elif isinstance(source, pd.DataFrame):
             progress = utils.get_progress_bar(4)
             progress.update("Partitioning data")
-            df = source if isinstance(source, pd.DataFrame) else source.compute()
+            df = source
             name = "User Provided DataFrame" if name is None else name
         else:
             raise TypeError(
                 f"The Source type: {type(source)} is not supported for DatasetFactory."
             )
         shape = df.shape
-        ddf = dd.from_pandas(
-            df,
-            npartitions=_num_partitions_for_dataframe(df)
-            if npartitions is None
-            else npartitions,
-        )
         return DatasetFactory._build_dataset(
-            ddf=ddf,
+            df=df,
             shape=shape,
             target=target,
             sample_max_rows=sample_max_rows,
@@ -234,15 +219,14 @@ class DatasetFactory:
         return df
 
     @staticmethod
-    def from_dataframe(df, target: str = None, npartitions: int = None, **kwargs):
+    def from_dataframe(df, target: str = None, **kwargs):
         """
-        Returns an object of ADSDatasetWithTarget or ADSDataset  given a pandas.DataFrame or dask.dataframe.core.DataFrame
+        Returns an object of ADSDatasetWithTarget or ADSDataset given a pandas.DataFrame
 
         Parameters
         ----------
-        df: Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
+        df: pandas.DataFrame
         target: str
-        npartitions: int
         kwargs: dict
             See DatasetFactory.open() for supported kwargs
 
@@ -256,7 +240,7 @@ class DatasetFactory:
 
         ds = from_dataframe(df)
         """
-        return DatasetFactory.open(df, target=target, npartitions=npartitions, **kwargs)
+        return DatasetFactory.open(df, target=target, **kwargs)
 
     @staticmethod
     def list_snapshots(snapshot_dir=None, name="", storage_options=None, **kwargs):
@@ -339,6 +323,13 @@ class DatasetFactory:
 
         # display in HTML format if sdk is run in notebook mode
         if utils.is_notebook():
+
+            try:
+                from ipywidgets import HTML
+            except ModuleNotFoundError as e:
+                utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
+                raise e
+
             display(
                 HTML(
                     list_df.style.set_table_attributes("class=table")
@@ -402,7 +393,7 @@ class DatasetFactory:
                     if os.path.exists(local_filepath) and not overwrite:
                         raise FileExistsError(
                             f"Trying to overwrite files in {local_filepath}. If you'd like to "
-                            f"overwrite these files, please set force_overwrite to True."
+                            f"overwrite these files, set force_overwrite to True."
                         )
                     os.makedirs(os.path.dirname(local_filepath), exist_ok=True)
                     with open(local_filepath, "wb") as f2:
@@ -491,7 +482,7 @@ class DatasetFactory:
     @classmethod
     def _build_dataset(
         cls,
-        ddf: dd.DataFrame,
+        df: pd.DataFrame,
         shape: Tuple[int, int],
         target: str = None,
         progress=None,
@@ -502,7 +493,7 @@ class DatasetFactory:
             progress.update("Generating data sample")
 
         sampled_df = generate_sample(
-            ddf,
+            df,
             n,
             DatasetDefaults.sampling_confidence_level,
             DatasetDefaults.sampling_confidence_interval,
@@ -512,7 +503,7 @@ class DatasetFactory:
         if target is None:
             if progress:
                 progress.update("Building the dataset with no target.")
-            result = ADSDataset(ddf=ddf, sampled_df=sampled_df, shape=shape, **kwargs)
+            result = ADSDataset(df=df, sampled_df=sampled_df, shape=shape, **kwargs)
             if progress:
                 progress.update("Done")
             logger.info(
@@ -534,7 +525,7 @@ class DatasetFactory:
         )
 
         result = DatasetFactory._get_dataset(
-            ddf=ddf,
+            df=df,
             sampled_df=sampled_df,
             target=target,
             target_type=target_type,
@@ -562,7 +553,7 @@ class DatasetFactory:
     @classmethod
     def _get_dataset(
         cls,
-        ddf: dd.DataFrame,
+        df: pd.DataFrame,
         sampled_df: pd.DataFrame,
         target: str,
         target_type: TypedFeature,
@@ -570,7 +561,7 @@ class DatasetFactory:
         positive_class=None,
         **init_kwargs,
     ):
-        if len(ddf[target].dropna()) == 0:
+        if len(df[target].dropna()) == 0:
             logger.warning(
                 "It is not recommended to use an empty column as the target variable."
             )
@@ -579,7 +570,7 @@ class DatasetFactory:
             )
         if is_same_class(target_type, ContinuousTypedFeature):
             return RegressionDataset(
-                ddf=ddf,
+                df=df,
                 sampled_df=sampled_df,
                 target=target,
                 target_type=target_type,
@@ -588,9 +579,9 @@ class DatasetFactory:
             )
         elif is_same_class(
             target_type, DateTimeTypedFeature
-        ) or ddf.index.dtype.name.startswith("datetime"):
+        ) or df.index.dtype.name.startswith("datetime"):
             return ForecastingDataset(
-                ddf=ddf,
+                df=df,
                 sampled_df=sampled_df,
                 target=target,
                 target_type=target_type,
@@ -605,7 +596,7 @@ class DatasetFactory:
             if target_type.meta_data["internal"]["unique"] == 2:
                 if is_text_data(sampled_df, target):
                     return BinaryTextClassificationDataset(
-                        ddf=ddf,
+                        df=df,
                         sampled_df=sampled_df,
                         target=target,
                         shape=shape,
@@ -615,7 +606,7 @@ class DatasetFactory:
                     )
 
                 return BinaryClassificationDataset(
-                    ddf=ddf,
+                    df=df,
                     sampled_df=sampled_df,
                     target=target,
                     shape=shape,
@@ -626,7 +617,7 @@ class DatasetFactory:
             else:
                 if is_text_data(sampled_df, target):
                     return MultiClassTextClassificationDataset(
-                        ddf=ddf,
+                        df=df,
                         sampled_df=sampled_df,
                         target=target,
                         target_type=target_type,
@@ -634,7 +625,7 @@ class DatasetFactory:
                         **init_kwargs,
                     )
                 return MultiClassClassificationDataset(
-                    ddf=ddf,
+                    df=df,
                     sampled_df=sampled_df,
                     target=target,
                     target_type=target_type,
@@ -661,7 +652,7 @@ class DatasetFactory:
         #   binary target, but only data on one instance
         elif target_type["low_level_type"] == "bool":
             return BinaryClassificationDataset(
-                ddf=ddf,
+                df=df,
                 sampled_df=sampled_df,
                 target=target,
                 shape=shape,
@@ -670,7 +661,7 @@ class DatasetFactory:
                 **init_kwargs,
             )
         raise ValueError(
-            f"Unable to identify problem type. Please specify the data type of {target} using 'types'. "
+            f"Unable to identify problem type. Specify the data type of {target} using 'types'. "
             f"For example, types = {{{target}: 'category'}}"
         )
 
@@ -709,7 +700,12 @@ class CustomFormatReaders:
 
     @staticmethod
     def read_avro(path: str, **kwargs) -> pd.DataFrame:
-        from pandavro import read_avro
+
+        try:
+            from pandavro import read_avro
+        except ModuleNotFoundError as e:
+            utils._log_missing_module("pandavro", "oracle-ads[data]")
+            raise e
 
         return read_avro(path, **kwargs)
 
@@ -729,7 +725,6 @@ class CustomFormatReaders:
         :param kwargs:
         :return: pd.DataFrame
         """
-        # ToDo: needs some love from the ADB story
         if table is None:
             raise ValueError(
                 "In order to read from a database you need to specify the table using the `table` "
@@ -851,7 +846,7 @@ class CustomFormatReaders:
         path: str
             Path to XML file
         storage_options: dict, optional
-            Storage options passed to dask to read the file
+            Storage options passed to Pandas to read the file.
         Returns
         -------
         dataframe : pandas.DataFrame
@@ -923,7 +918,7 @@ def get_format_reader(path: ElaboratedPath, **kwargs) -> Callable:
     except (KeyError, NameError):
         raise ValueError(
             f"We were unable to load the specified dataset. We have interpreted the format "
-            f"as {format_key}, if this is not correct, please call again and set the `format` parameter = "
+            f"as {format_key}, if this is not correct, call again and set the `format` parameter = "
             f"to the desired format. Read more here: https://docs.cloud.oracle.com/en-us/iaas/tools/ads"
             f"-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset"
         )
@@ -940,7 +935,7 @@ def load_dataset(path: ElaboratedPath, reader_fn: Callable, **kwargs) -> pd.Data
             raise ValueError(
                 f"{fn_name} is used to load the data. "
                 f"However, {fn_name} returned {type(data)} instead of pandas DataFrame. "
-                f"Please refer to the usage of {fn_name} to set the correct arguments."
+                f"Refer to the usage of {fn_name} to set the correct arguments."
             )
         dfs.append(data)
     if len(dfs) == 0:
