@@ -6,18 +6,16 @@
 
 import ast
 import base64
-import copy
 import html
 import io
 import math
 import os
 import warnings
 import re
-import warnings
 from collections import defaultdict
 import inspect
 import importlib
-from typing import List, Callable, Union
+from typing import List, Union
 import fsspec
 
 from pandas.io.common import _compression_to_extension
@@ -25,16 +23,10 @@ from pandas.io.common import _compression_to_extension
 from numbers import Number
 from urllib.parse import urlparse
 
-import dask
-import dask.dataframe as dd
-
 import numpy as np
 import pandas as pd
 
 from IPython.core.display import display, SVG
-import cloudpickle
-from fastparquet import ParquetFile, parquet_thrift
-from fastparquet.writer import write_common_metadata
 from graphviz import Digraph, Source
 from pandas.core.dtypes.common import (
     is_numeric_dtype,
@@ -241,7 +233,7 @@ class ElaboratedPath:
                 )
             if format_keys.count(format_keys[0]) != len(format_keys):
                 raise ValueError(
-                    f"Got multiple formats from the source: {self._original_source}. Please run again "
+                    f"Got multiple formats from the source: {self._original_source}. Run again "
                     f'using the format parameter. Ex: format=<your format key, like: "csv", "hdf", etc.>'
                 )
             self._format = format_keys[0]
@@ -320,9 +312,8 @@ def _get_dtype_from_error(e):
             found_dtype_dict = _find_dtypes_from_table(error_string)
         if found_dtype_dict:
             logger.warning(
-                "Dask type-inference/coercion failed. Retrying with dtype=%s.".format(
-                    found_dtype_dict
-                ),
+                "Dask type-inference/coercion failed. Retrying with "
+                f"dtype={found_dtype_dict}.",
                 exc_info=True,
             )
             return found_dtype_dict
@@ -348,22 +339,6 @@ def _find_dtypes_from_table(error_string):
     return dtypes
 
 
-# convert spark dataframe into dask dataframe
-def _spark_to_dask(sdf):
-    df_dask = sdf.rdd.mapPartitions(_map_to_pandas).collect()
-    if len(df_dask) == 1:
-        # edge case handling: when the spark dataframe is not partitioned, meaning npartition = 1
-        df_dask = dd.from_pandas(df_dask[0], npartitions=1)
-    else:
-        df_dask = dd.concat(df_dask)
-    df_dask.columns = sdf.columns
-    return df_dask
-
-
-def _map_to_pandas(rdds):
-    return [pd.DataFrame(list(rdds))]
-
-
 def rename_duplicate_cols(original_cols):
     seen_col_names = defaultdict(int)
     new_cols = []
@@ -383,7 +358,14 @@ def rename_duplicate_cols(original_cols):
     return new_cols
 
 
-def write_parquet(path, data, metadata_dict={}, storage_options=None):
+def write_parquet(
+    path,
+    data,
+    engine="fastparquet",
+    metadata_dict=None,
+    compression=None,
+    storage_options=None,
+):
     """
     Uses fast parquet to write dask dataframe and custom metadata in parquet format
 
@@ -391,43 +373,32 @@ def write_parquet(path, data, metadata_dict={}, storage_options=None):
     ----------
     path : str
         Path to write to
-    data : dask.dataframe.core.DataFrame
-    metadata_dict: dict, optional
-         custom metadata for parquet file
-    open_with: function, optional
-         function to open the given path
-         Uses local file system open if None
-    storage_options: dict, optional
+    data : pandas.DataFrame
+    engine : string
+        "auto" by default
+    metadata_dict : Deprecated, will not pass through
+    compression : {{'snappy', 'gzip', 'brotli', None}}, default 'snappy'
+        Name of the compression to use
+    storage_options : dict, optional
         storage arguments required to read the path
 
     Returns
     -------
-    pf : ParquetFile
+    str : the file path the parquet was written to
     """
-    assert isinstance(data, dask.dataframe.core.DataFrame)
-
-    # Write dataframe
-    data.to_parquet(path, compression="GZIP", storage_options=storage_options)
-
-    # # Open file
-    # open_with = fsspec.open_files(path, mode='rb', **storage_options)[0].fs.open
-    # pf = ParquetFile(path, open_with=open_with)
-    #
-    # # Add metadata
-    # new_fmd = copy.copy(pf.fmd)
-    # for key in metadata_dict.keys():
-    #     metadata_key = parquet_thrift.KeyValue()
-    #     metadata_key.key = key
-    #     metadata_key.value = base64.b64encode(cloudpickle.dumps(metadata_dict[key])).decode('utf8')
-    #     new_fmd.key_value_metadata.append(metadata_key)
-    #
-    # # Overwrite file metadata
-    # fn = os.path.join(path, '_metadata')
-    # write_common_metadata(fn, new_fmd, no_row_groups=False, open_with=open_with)
-    #
-    # fn = os.path.join(path, '_common_metadata')
-    # write_common_metadata(fn, new_fmd, open_with=open_with)
-
+    assert isinstance(data, pd.DataFrame)
+    if metadata_dict is not None:
+        warnings.warn(
+            "The `metadata_dict` argument is deprecated and has no effect on this method.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+    data.to_parquet(
+        path,
+        engine=engine,
+        compression=compression,
+        storage_options=storage_options,
+    )
     return path
 
 
@@ -449,7 +420,7 @@ def is_text_data(df, target=None):
 
 
 def generate_sample(
-    ddf: dd.DataFrame,
+    df: pd.DataFrame,
     n: int,
     confidence_level: int = DatasetDefaults.sampling_confidence_level,
     confidence_interval: float = DatasetDefaults.sampling_confidence_interval,
@@ -481,12 +452,12 @@ def generate_sample(
                     f"Downsampling from {n} rows, to {sample_size} rows for graphing."
                 )
 
-    if sample_size and len(ddf) > sample_size:
+    if sample_size and len(df) > sample_size:
         frac = min(1.0, sample_size * 1.05 / n)
-        df = ddf.sample(frac=frac, random_state=42).compute()
+        df = df.sample(frac=frac, random_state=42)
         return df.head(sample_size) if len(df) > sample_size else df
     else:
-        return ddf.compute()
+        return df
 
 
 def calculate_sample_size(
@@ -674,7 +645,7 @@ def up_sample(df, target, sampler="default", feature_types=None):
             raise ModuleNotFoundError(
                 """
                 Required package for up-sampling `imblearn` not found.
-                Please install `imblearn` with `pip install imbalanced-learn`
+                Install `imblearn` with `pip install imbalanced-learn`
                 and rerun to enable up-sampling.
             """
             )
@@ -705,10 +676,7 @@ def _get_imblearn_sampler(X, y):
         )
         return RandomOverSampler(random_state=42)
 
-    if isinstance(y, pd.Series) or isinstance(y, pd.DataFrame):
-        min_sample_size = y.value_counts().min()
-    else:
-        min_sample_size = y.value_counts().min().compute()
+    min_sample_size = y.value_counts().min()
 
     k_neighbors = min(min_sample_size - 1, 5)
     if k_neighbors == 0:
@@ -735,19 +703,14 @@ def down_sample(df, target):
 
     Parameters
     ----------
-    df : Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
+    df : pandas.DataFrame
     target : name of the target column in df
 
     Returns
     -------
-    downsampled_df : Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
+    downsampled_df : pandas.DataFrame
     """
     dfs = []
-    if isinstance(df, dd.core.DataFrame) and all(
-        [division is None for division in df.divisions]
-    ):
-        # for dask dataframes, calling set_index will set the divisions. Concatenation with unknown divisions fails.
-        df = df.reset_index().set_index("index")
     target_value_counts = df[target].value_counts()
     min_key = min(target_value_counts.iteritems(), key=lambda k: k[1])
     for key, value in target_value_counts.iteritems():
@@ -756,11 +719,7 @@ def down_sample(df, target):
                 df[df[target] == key].sample(frac=1 - ((value - min_key[1]) / value))
             )
     dfs.append(df[df[target] == min_key[0]])
-    return (
-        pd.concat(dfs)
-        if isinstance(df, pd.DataFrame)
-        else dd.concat(dfs, interleave_partitions=True)
-    )
+    return pd.concat(dfs)
 
 
 def _sample(sampler, X, y):
@@ -772,23 +731,15 @@ def _sample(sampler, X, y):
     else:
         X_resampled, y_resampled = sampler.fit_resample(X=X, y=y)
 
-    if isinstance(X_resampled, pd.DataFrame):
-        X_resampled = dd.from_pandas(
-            X_resampled, npartitions=_num_partitions_for_dataframe(X_resampled)
-        )
-    else:
-        X_resampled = dd.from_array(X_resampled, columns=X.columns.values)
-    if isinstance(y_resampled, pd.Series):
-        y_resampled = dd.from_pandas(
-            y_resampled, npartitions=_num_partitions_for_dataframe(y_resampled)
-        )
-    else:
-        y_resampled = dd.from_array(y_resampled, columns=[y.name])[y.name]
+    if not isinstance(X_resampled, pd.DataFrame):
+        X_resampled = pd.DataFrame(X_resampled, columns=X.columns.values)
+    if not isinstance(y_resampled, pd.Series):
+        y_resampled = pd.DataFrame(y_resampled, columns=[y.name])[y.name]
 
     for k in X.dtypes.keys():
         X_resampled[k] = X_resampled[k].astype(X.dtypes[k].name)
     balanced_df = concatenate(X_resampled, y_resampled)
-    return balanced_df.compute() if isinstance(X, pd.DataFrame) else balanced_df
+    return balanced_df
 
 
 def get_fill_val(feature_types, column, action, constant="constant"):
