@@ -9,7 +9,6 @@ from abc import abstractmethod
 
 import six
 from IPython.core.display import display
-from ipywidgets import Label, IntProgress
 from tqdm import tqdm_notebook
 
 
@@ -30,6 +29,17 @@ class ProgressBar(object):
 class IpythonProgressBar(ProgressBar):
     def __init__(self, max_progress=100, description="Running", verbose=False):
         self.max_progress = max_progress
+
+        from ads.common import logger
+
+        try:
+            from ipywidgets import Label, IntProgress
+        except ModuleNotFoundError as e:
+            logger.error(
+                f"The ipywidgets module was not found. Install oracle-ads[notebook]."
+            )
+            raise e
+
         self.progress_label = Label(description)
         self.progress_bar = IntProgress(min=0, max=max_progress)
         self.verbose = verbose
@@ -69,6 +79,17 @@ class TqdmProgressBar(ProgressBar):
 
     def __init__(self, max_progress=100, description="Running", verbose=False):
         self.max_progress = max_progress
+
+        from ads.common import logger
+
+        try:
+            import ipywidgets
+        except ModuleNotFoundError as e:
+            logger.error(
+                f"The ipywidgets module was not found. Install oracle-ads[notebook]."
+            )
+            raise e
+
         self.progress_bar = tqdm_notebook(
             range(max_progress), desc="loop1", mininterval=0, leave=False
         )
