@@ -15,7 +15,6 @@ import math
 from ads.common import utils, logger, model
 import itertools
 from IPython.core.display import display
-from ipywidgets import HTML
 import pandas as pd
 
 MAX_TITLE_LEN = 20
@@ -185,6 +184,13 @@ class EvaluationPlot:
                 pd.Series(label_dict, index=label_dict.keys()),
                 columns=["Shortened labels"],
             )
+
+            try:
+                from ipywidgets import HTML
+            except ModuleNotFoundError as e:
+                utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
+                raise e
+
             display(
                 HTML(
                     encodings.style.set_precision(4)
