@@ -8,7 +8,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from IPython.core.display import display
-from ipywidgets import HTML
 
 from cycler import cycler
 import matplotlib as mpl
@@ -153,7 +152,6 @@ class ADSEvaluator(object):
         self.positive_class = pclass
         self.legend_labels = legend_labels
 
-        # TODO: revise function to convert any model into ADS Model
         for m in models:
             if not (isinstance(m, ADSModel)):
                 try:
@@ -565,6 +563,13 @@ class ADSEvaluator(object):
                 Returns:
                     Nothing
                 """
+
+                try:
+                    from ipywidgets import HTML
+                except ModuleNotFoundError as e:
+                    utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
+                    raise e
+
                 display(
                     HTML(
                         _pretty_label(df, labels)
