@@ -127,7 +127,7 @@ class ModelEvaluator:
         normalized_cm = np.divide(a, b, out=np.zeros_like(a), where=b != 0).tolist()
         self.metrics["confusion_matrix"] = normalized_cm
 
-        vc = self.y_true.value_counts()
+        vc = pd.DataFrame(self.y_true).value_counts()
         self.metrics["class_balance"] = min(vc) / max(vc)
 
     def _get_binary_metrics(self):
