@@ -5,6 +5,10 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 from typing import List, Union
 
+import fsspec
+from urllib.parse import urlparse
+
+from ads.common.auth import default_signer
 from ads.jobs.builders.runtimes.container_runtime import ContainerRuntime
 from ads.jobs.builders.base import Builder
 from ads.jobs.builders.infrastructure.dataflow import DataFlow, DataFlowRun
@@ -20,6 +24,77 @@ from ads.jobs.builders.runtimes.python_runtime import (
 
 
 class Job(Builder):
+    """Represents a Job containing infrastructure and runtime.
+
+    Example
+    -------
+    Here is an example for creating and running a job:
+
+    .. code-block:: python
+        
+        from ads.jobs import Job, DataScienceJob, PythonRuntime
+        # Define an OCI Data Science job to run a python script
+        job = (
+            Job(name="<job_name>")
+            .with_infrastructure(
+                DataScienceJob()
+                .with_compartment_id("<compartment_ocid>")
+                .with_project_id("<project_ocid>")
+                .with_subnet_id("<subnet_ocid>")
+                .with_shape_name("VM.Standard2.1")
+                .with_block_storage_size(50)
+                .with_log_group_id("<log_group_ocid>")
+                .with_log_id("<log_ocid>")
+            )
+            .with_runtime(
+                PythonRuntime()
+                .with_source("oci://bucket_name@namespace/path/to/script.py")
+                .with_service_conda("tensorflow26_p37_cpu_v2")
+                .with_environment_variable(ENV="value")
+                .with_argument("argument", key="value")
+                .with_freeform_tag(tag_name="tag_value")
+            )
+        )
+        # Create and Run the job
+        run = job.create().run()
+        # Stream the job run outputs
+        run.watch()
+
+    If you are in an OCI notebook session and you would like to use the same infrastructure
+    configurations, the infrastructure configuration can be simplified.
+    Here is another example of creating and running a jupyter notebook as a job:
+
+    .. code-block:: python
+
+        from ads.jobs import Job, DataScienceJob, NotebookRuntime
+        # Define an OCI Data Science job to run a jupyter Python notebook
+        job = (
+            Job(name="<job_name>")
+            .with_infrastructure(
+                # The same configurations as the OCI notebook session will be used.
+                DataScienceJob()
+                .with_log_group_id("<log_group_ocid>")
+                .with_log_id("<log_ocid>")
+            )
+            .with_runtime(
+                NotebookRuntime()
+                .with_notebook("path/to/notebook.ipynb")
+                .with_service_conda(tensorflow26_p37_cpu_v2")
+                # Saves the notebook with outputs to OCI object storage.
+                .with_output("oci://bucket_name@namespace/path/to/dir")
+            )
+        ).create()
+        # Run and monitor the job
+        run = job.run().watch()
+        # Download the notebook and outputs to local directory
+        run.download(to_dir="path/to/local/dir/")
+
+
+    See Also
+    --------
+    https://docs.oracle.com/en-us/iaas/tools/ads-sdk/latest/user_guide/jobs/index.html
+
+    """
 
     _INFRASTRUCTURE_MAPPING = {
         **{item().type: item for item in [DataScienceJob]},
@@ -397,3 +472,46 @@ class Job(Builder):
                 job.set_spec(key, value)
 
         return job
+
+    def download(self, to_dir: str, output_uri=None, **storage_options):
+        """Downloads files from remote output URI to local.
+
+        Parameters
+        ----------
+        to_dir : str
+            Local directory to which the files will be downloaded to.
+
+        output_uri : (str, optional). Default is None.
+            The remote URI from which the files will be downloaded.
+            Defaults to None.
+            If output_uri is not specified, this method will try to get the output_uri from the runtime.
+
+        storage_options :
+            Extra keyword arguments for particular storage connection.
+            This method uses fsspec to download the files from remote URI.
+            storage_options will to be passed into fsspec.open_files().
+
+        Returns
+        -------
+        Job
+            The job instance (self)
+
+        Raises
+        ------
+        AttributeError
+            The output_uri is not specified and the runtime is not configured with output_uri.
+        """
+        if not output_uri and self.runtime:
+            output_uri = getattr(self.runtime, "output_uri", None)
+
+        if not output_uri:
+            raise AttributeError(
+                "Please specify the output_uri or set it with a compatible runtime."
+            )
+
+        scheme = urlparse(output_uri).scheme
+        if scheme == "oci" and not storage_options:
+            storage_options = default_signer()
+        fs = fsspec.filesystem(scheme, **storage_options)
+        fs.get(self.runtime.output_uri, to_dir, recursive=True)
+        return self
