@@ -632,7 +632,7 @@ class DataFlow(Infrastructure):
         )
         if not payload.get("compartment_id", None):
             raise ValueError(
-                "Compartment id is required. Please specify compartment id via 'with_compartment_id()'."
+                "Compartment id is required. Specify compartment id via 'with_compartment_id()'."
             )
         payload.pop("id", None)
         logger.debug(f"Creating a DataFlow Application with payload {payload}")
