@@ -33,7 +33,9 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
     Mainly, linking the Job model (payload) to Create/Update/Get/List/Delete methods.
 
     A DSCJob can be initialized by unpacking a the properties stored in a dictionary (payload):
+
     .. code-block:: python
+
         job_properties = {
             "display_name": "my_job,
             "job_infrastructure_configuration_details": {"shape_name": "VM.MY_SHAPE"}
@@ -41,7 +43,9 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
         job = DSCJob(**job_properties)
 
     The properties can also be OCI REST API payload, in which the keys are in camel format.
+
     .. code-block:: python
+
         job_payload = {
             "projectId": "<project_ocid>",
             "compartmentId": "<compartment_ocid>",
@@ -196,9 +200,9 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
         self.load_properties_from_env()
         # Check compartment ID and project ID before calling the OCI API
         if not self.compartment_id:
-            raise ValueError("Please specify compartment ID for data science job.")
+            raise ValueError("Specify compartment ID for data science job.")
         if not self.project_id:
-            raise ValueError("Please specify project ID for data science job.")
+            raise ValueError("Specify project ID for data science job.")
         self._create_with_oci_api()
         return self
 
@@ -293,11 +297,11 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
         **kwargs :
             Keyword arguments for initializing a Data Science Job Run.
             The keys can be any keys in supported by OCI JobConfigurationDetails and JobRun, including:
-            hyperparameter_values: dict(str, str)
-            environment_variables: dict(str, str)
-            command_line_arguments: str
-            maximum_runtime_in_minutes: int
-            display_name: str
+            * hyperparameter_values: dict(str, str)
+            * environment_variables: dict(str, str)
+            * command_line_arguments: str
+            * maximum_runtime_in_minutes: int
+            * display_name: str
 
         If display_name is not specified, it will be generated as "<JOB_NAME>-run-<TIMESTAMP>"
 
@@ -576,6 +580,35 @@ class DataScienceJobRun(
         """
         return yaml.safe_dump(self.to_dict())
 
+    @property
+    def job(self):
+        """The job instance of this run.
+
+        Returns
+        -------
+        Job
+            An ADS Job instance
+        """
+        from ads.jobs import Job
+
+        return Job.from_datascience_job(self.job_id)
+
+    def download(self, to_dir):
+        """Downloads files from job run output URI to local.
+
+        Parameters
+        ----------
+        to_dir : str
+            Local directory to which the files will be downloaded to.
+
+        Returns
+        -------
+        DataScienceJobRun
+            The job run instance (self)
+        """
+        self.job.download(to_dir)
+        return self
+
 
 # This is for backward compatibility
 DSCJobRun = DataScienceJobRun
@@ -976,7 +1009,7 @@ class DataScienceJob(Infrastructure):
 
         """
         if not runtime:
-            raise ValueError("Please set a valid runtime.")
+            raise ValueError("Set a valid runtime.")
         payload = DataScienceJobRuntimeManager(self).translate(runtime)
         # Add infra properties to payload
         for attr in ["project_id", "compartment_id"]:
@@ -1020,7 +1053,7 @@ class DataScienceJob(Infrastructure):
         # Runtime in the infrastructure will be None if the job is not created.
         if not self.runtime:
             raise RuntimeError(
-                "Job is not created. Please call create() to create the job first."
+                "Job is not created. Call create() to create the job first."
             )
         tags = self.runtime.freeform_tags
         if not tags:
