@@ -14,6 +14,7 @@ The conversion from a DSCJob to a runtime is called extract in this module.
 """
 from __future__ import annotations
 
+import json
 import os
 import shlex
 from typing import Optional
@@ -377,15 +378,14 @@ class CondaRuntimeHandler(RuntimeHandler):
     def __get_auth_region(self) -> str:
         config = self.data_science_job.dsc_job.auth.get("config")
         signer = self.data_science_job.dsc_job.auth.get("signer")
-        if 'region' in config and config['region']:
-            region_to_use = config.get('region')
-        elif hasattr(signer, 'region'):
+        if "region" in config and config["region"]:
+            region_to_use = config.get("region")
+        elif hasattr(signer, "region"):
             region_to_use = signer.region
         else:
             region_to_use = None
         return region_to_use
 
-
     def _translate_env(self, runtime: CondaRuntime) -> dict:
         """Translate the environment variable.
 
@@ -401,14 +401,24 @@ class CondaRuntimeHandler(RuntimeHandler):
         """
         envs = super()._translate_env(runtime)
         if runtime.conda:
-            envs[self.CONST_CONDA_TYPE] = runtime.conda.get(PythonRuntime.CONST_CONDA_TYPE)
-            if runtime.conda.get(PythonRuntime.CONST_CONDA_TYPE) == PythonRuntime.CONST_CONDA_TYPE_SERVICE:
+            envs[self.CONST_CONDA_TYPE] = runtime.conda.get(
+                PythonRuntime.CONST_CONDA_TYPE
+            )
+            if (
+                runtime.conda.get(PythonRuntime.CONST_CONDA_TYPE)
+                == PythonRuntime.CONST_CONDA_TYPE_SERVICE
+            ):
                 envs.update(
                     {
-                        self.CONST_CONDA_SLUG: runtime.conda.get(PythonRuntime.CONST_CONDA_SLUG),
+                        self.CONST_CONDA_SLUG: runtime.conda.get(
+                            PythonRuntime.CONST_CONDA_SLUG
+                        ),
                     }
                 )
-            elif runtime.conda.get(PythonRuntime.CONST_CONDA_TYPE) == PythonRuntime.CONST_CONDA_TYPE_CUSTOM:
+            elif (
+                runtime.conda.get(PythonRuntime.CONST_CONDA_TYPE)
+                == PythonRuntime.CONST_CONDA_TYPE_CUSTOM
+            ):
                 uri = runtime.conda.get(PythonRuntime.CONST_CONDA_URI)
                 p = parse.urlparse(uri)
                 if not (p.username and p.hostname and p.path):
@@ -420,14 +430,14 @@ class CondaRuntimeHandler(RuntimeHandler):
                 if not region:
                     raise AttributeError(
                         "Unable to determine the region for the custom conda pack. "
-                        "Please specify the region using with_custom_conda(uri, region)."
+                        "Specify the region using with_custom_conda(uri, region)."
                     )
                 envs.update(
                     {
                         self.CONST_CONDA_NAMESPACE: p.hostname,
                         self.CONST_CONDA_BUCKET: p.username,
                         self.CONST_CONDA_OBJ_NAME: p.path.lstrip("/"),
-                        self.CONST_CONDA_REGION: region
+                        self.CONST_CONDA_REGION: region,
                     }
                 )
         return envs
@@ -560,15 +570,50 @@ class NotebookRuntimeHandler(CondaRuntimeHandler):
     """Runtime Handler for NotebookRuntime"""
 
     RUNTIME_CLASS = NotebookRuntime
+    CONST_NOTEBOOK_NAME = "JOB_RUN_NOTEBOOK"
+    CONST_ENTRYPOINT = "JOB_RUN_ENTRYPOINT"
+    CONST_OUTPUT_URI = "OUTPUT_URI"
+    CONST_EXCLUDE_TAGS = "NOTEBOOK_EXCLUDE_TAGS"
+
+    SPEC_MAPPINGS = {
+        NotebookRuntime.CONST_NOTEBOOK_PATH: CONST_NOTEBOOK_NAME,
+        NotebookRuntime.CONST_OUTPUT_URI: CONST_OUTPUT_URI,
+        NotebookRuntime.CONST_TAG: CONST_EXCLUDE_TAGS,
+    }
 
     def _translate_artifact(self, runtime: NotebookRuntime):
         return NotebookArtifact(runtime.notebook_uri, runtime)
 
-    def extract(self, dsc_job):
-        """Extracting NotebookRuntime is not implemented yet.
-        Notebook runtime will be extracted as PythonRuntime
+    def _translate_env(self, runtime: NotebookRuntime) -> dict:
+        envs = super()._translate_env(runtime)
+        envs[self.CONST_NOTEBOOK_NAME] = os.path.basename(runtime.notebook_uri)
+        envs[self.CONST_ENTRYPOINT] = NotebookArtifact.CONST_DRIVER_SCRIPT
+        if runtime.exclude_tag:
+            envs[self.CONST_EXCLUDE_TAGS] = json.dumps(runtime.exclude_tag)
+        if runtime.output_uri:
+            envs[self.CONST_OUTPUT_URI] = runtime.output_uri
+        return envs
+
+    def _extract_envs(self, dsc_job) -> dict:
+        """Extract the runtime specification from environment variables.
+
+        Parameters
+        ----------
+        dsc_job : DSCJob or oci.datascience.models.Job
+            The data science job containing runtime information.
+
+        Returns
+        -------
+        dict
+            A runtime specification dictionary for initializing a runtime.
         """
-        raise IncompatibleRuntime()
+        spec = super()._extract_envs(dsc_job)
+        envs = spec.pop(NotebookRuntime.CONST_ENV_VAR, {})
+        if self.CONST_NOTEBOOK_NAME not in envs:
+            raise IncompatibleRuntime()
+        spec.update(self._extract_specs(envs, self.SPEC_MAPPINGS))
+        spec[NotebookRuntime.CONST_ENV_VAR] = envs
+        return spec
 
 
 class GitPythonRuntimeHandler(CondaRuntimeHandler):
@@ -718,7 +763,7 @@ class ContainerRuntimeHandler(RuntimeHandler):
             A dictionary contianing environment variables for OCI data science job.
         """
         if not runtime.image:
-            raise ValueError("Please specify container image for ContainerRuntime.")
+            raise ValueError("Specify container image for ContainerRuntime.")
         envs = super()._translate_env(runtime)
         spec_mappings = {
             ContainerRuntime.CONST_IMAGE: self.CONST_CONTAINER_IMAGE,
