@@ -3,14 +3,19 @@
 
 # Copyright (c) 2021 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+import contextlib
+import logging
 import os
 import shutil
 import tempfile
-
+import zipfile
 import fsspec
-import nbformat
-from nbconvert import PythonExporter, preprocessors
-from traitlets.config import Config
+from io import DEFAULT_BUFFER_SIZE
+from urllib import request
+from urllib.parse import urlparse
+from ads.common.auth import default_signer
+
+logger = logging.getLogger(__name__)
 
 
 class Artifact:
@@ -31,7 +36,11 @@ class Artifact:
     """
 
     def __init__(self, source, runtime=None) -> None:
-        self.source = source
+        # Get the full path of source file if it is local file.
+        if not urlparse(source).scheme:
+            self.source = os.path.abspath(os.path.expanduser(source))
+        else:
+            self.source = source
         self.path = None
         self.temp_dir = None
         self.runtime = runtime
@@ -67,29 +76,64 @@ class Artifact:
 class NotebookArtifact(Artifact):
     """Represents a NotebookRuntime job artifact"""
 
+    CONST_DRIVER_SCRIPT = "driver_notebook.py"
+
     def __init__(self, source, runtime) -> None:
         super().__init__(source, runtime=runtime)
 
+    @staticmethod
+    def _write_file(fp, to_path):
+        with open(to_path, "wb") as out_file:
+            block_size = DEFAULT_BUFFER_SIZE * 8
+            while True:
+                block = fp.read(block_size)
+                if not block:
+                    break
+                out_file.write(block)
+
+    @staticmethod
+    def _download_from_web(url, to_path):
+        url_response = request.urlopen(url)
+        with contextlib.closing(url_response) as fp:
+            logger.debug("Downloading from %s", url)
+            NotebookArtifact._write_file(fp, to_path)
+
+    @staticmethod
+    def _download_from_oci(uri, to_path):
+        """Uses ADS default config/signer to download data from OCI"""
+        with fsspec.open(uri, **default_signer()) as fp:
+            NotebookArtifact._write_file(fp, to_path)
+
+    def _copy_notebook(self, to_path):
+        scheme = urlparse(self.source).scheme
+        if scheme in ["http", "https", "ftp"]:
+            self._download_from_web(self.source, to_path)
+        elif scheme == "oci":
+            # Add config/signer for downloading from oci
+            self._download_from_oci(self.source, to_path)
+        else:
+            # The config/signer should not be used for non-oci source
+            with fsspec.open(self.source) as fp:
+                NotebookArtifact._write_file(fp, to_path)
+
     def build(self):
         """Prepares job artifact for notebook runtime"""
-        self.path = os.path.join(
-            self.temp_dir.name,
-            str(os.path.basename(self.source)).replace(".ipynb", ".py"),
+        driver_script = os.path.join(
+            os.path.dirname(__file__), "../../templates", self.CONST_DRIVER_SCRIPT
         )
-        with fsspec.open(self.source) as f:
-            nb = nbformat.reads(f.read(), nbformat.NO_CONVERT)
-
-        exporter = PythonExporter()
-
-        if self.runtime != None and self.runtime.exclude_tag:
-            c = Config()
-            c.TagRemovePreprocessor.remove_cell_tags = self.runtime.exclude_tag
-            trp = preprocessors.TagRemovePreprocessor(config=c)
-            trp.preprocess(nb=nb, resources=None)
-        source, _ = exporter.from_notebook_node(nb)
-
-        with open(self.path, "wb") as f:
-            f.write(source.encode("utf-8"))
+        notebook_path = os.path.join(self.temp_dir.name, os.path.basename(self.source))
+        output_path = (
+            os.path.join(
+                self.temp_dir.name,
+                str(os.path.basename(self.source)).split(".", maxsplit=1)[0],
+            )
+            + ".zip"
+        )
+        self._copy_notebook(notebook_path)
+        with zipfile.ZipFile(output_path, "w") as zip_file:
+            zip_file.write(notebook_path, os.path.basename(notebook_path))
+            zip_file.write(driver_script, os.path.basename(driver_script))
+        self.path = output_path
 
 
 class ScriptArtifact(Artifact):
@@ -100,17 +144,16 @@ class ScriptArtifact(Artifact):
         If the source is a file, it will be returned as is.
         If the source is a directory, it will be compressed as a zip file.
         """
-        source = os.path.abspath(os.path.expanduser(self.source))
-        path, _ = os.path.splitext(source)
+        path, _ = os.path.splitext(self.source)
         basename = os.path.basename(str(path).rstrip("/"))
 
         # Zip the artifact if it is a directory
-        if os.path.isdir(source):
-            source = str(source).rstrip("/")
+        if os.path.isdir(self.source):
+            source = str(self.source).rstrip("/")
             # Runtime must have entrypoint if the source is a directory
             if not self.runtime.entrypoint:
                 raise ValueError(
-                    "Please specify entrypoint when script source is a directory."
+                    "Specify entrypoint when script source is a directory."
                 )
             output = os.path.join(self.temp_dir.name, basename)
             shutil.make_archive(
@@ -119,4 +162,4 @@ class ScriptArtifact(Artifact):
             self.path = output + ".zip"
             return
         # Otherwise, use the artifact directly
-        self.path = source
+        self.path = self.source
