@@ -50,8 +50,8 @@ class CondaRuntime(Runtime):
             self.CONST_CONDA,
             {
                 self.CONST_CONDA_TYPE: self.CONST_CONDA_TYPE_SERVICE,
-                self.CONST_CONDA_SLUG: slug
-            }
+                self.CONST_CONDA_SLUG: slug,
+            },
         )
 
     def with_custom_conda(self, uri: str, region: str = None):
@@ -67,8 +67,9 @@ class CondaRuntime(Runtime):
         region: str, optional
             The region of the bucket storing the custom conda pack, by default None.
             If region is not specified, ADS will use the region from your authentication credentials,
-                * For API Key, config["region"] is used.
-                * For Resource Principal, signer.region is used.
+            * For API Key, config["region"] is used.
+            * For Resource Principal, signer.region is used.
+
             This is required if the conda pack is stored in a different region.
 
         Returns
@@ -83,7 +84,7 @@ class CondaRuntime(Runtime):
         """
         conda_spec = {
             self.CONST_CONDA_TYPE: self.CONST_CONDA_TYPE_CUSTOM,
-            self.CONST_CONDA_URI: uri
+            self.CONST_CONDA_URI: uri,
         }
         if region:
             conda_spec[self.CONST_CONDA_REGION] = region
@@ -180,6 +181,7 @@ class NotebookRuntime(CondaRuntime):
     """Represents a job runtime with Jupyter notebook"""
 
     CONST_NOTEBOOK_PATH = "notebookPathURI"
+    CONST_OUTPUT_URI = "outputURI"
     EXCLUDE_TAG = "excludeTags"
 
     @property
@@ -187,7 +189,7 @@ class NotebookRuntime(CondaRuntime):
         """The URI of the notebook"""
         return self.get_spec(self.CONST_NOTEBOOK_PATH)
 
-    def with_notebook(self, path):
+    def with_notebook(self, path: str):
         """Specifies the notebook to be converted to python script and run as a job.
 
         Parameters
@@ -207,21 +209,48 @@ class NotebookRuntime(CondaRuntime):
         """A list of cell tags indicating cells to be excluded from the job"""
         return self.get_spec(self.EXCLUDE_TAG, [])
 
-    def with_exclude_tag(self, exclude_tag_list):
+    def with_exclude_tag(self, *tags):
         """Specifies the cell tags in the notebook to exclude cells from the job script.
 
         Parameters
         ----------
-        exclude_tag_list : list
-            A list of tags.
+        *tags : list
+            A list of tags (strings).
 
         Returns
         -------
         self
             The runtime instance.
         """
+        exclude_tag_list = []
+        for tag in tags:
+            if isinstance(tag, list):
+                exclude_tag_list.extend(tag)
+            else:
+                exclude_tag_list.append(tag)
         return self.set_spec(self.EXCLUDE_TAG, exclude_tag_list)
 
+    @property
+    def output_uri(self) -> list:
+        """URI for storing the output notebook and files"""
+        return self.get_spec(self.CONST_OUTPUT_URI)
+
+    def with_output(self, output_uri: str):
+        """Specifies the output URI for storing the output notebook and files.
+
+        Parameters
+        ----------
+        output_uri : str
+            URI for storing the output notebook and files.
+            For example, oci://bucket@namespace/path/to/dir
+
+        Returns
+        -------
+        self
+            The runtime instance.
+        """
+        return self.set_spec(self.CONST_OUTPUT_URI, output_uri)
+
 
 class GitPythonRuntime(CondaRuntime):
     """Represents a job runtime with source code from git repository"""
@@ -247,11 +276,12 @@ class GitPythonRuntime(CondaRuntime):
         skip_metadata_update : bool, optional
             Indicate if the metadata update should be skipped after the job run, by default False.
             By default, the job run metadata will be updated with the following freeform tags:
-                repo: The URL of the Git repository
-                commit: The Git commit ID
-                module: The entry script/module
-                method: The entry function/method
-                outputs. The prefix of the output files in object storage.
+            * repo: The URL of the Git repository
+            * commit: The Git commit ID
+            * module: The entry script/module
+            * method: The entry function/method
+            * outputs. The prefix of the output files in object storage.
+
             This update step also requires resource principals to have the permission to update the job run.
         """
         super().__init__(spec=spec)
@@ -342,7 +372,7 @@ class GitPythonRuntime(CondaRuntime):
         """The name of the entry function in the entry script"""
         return self.get_spec(self.CONST_ENTRY_FUNCTION)
 
-    def with_output(self, output_dir, output_uri):
+    def with_output(self, output_dir: str, output_uri: str):
         """Specifies the outputs of the job.
         The outputs will be copied to the object storage bucket when the job is finished.
 
@@ -381,7 +411,7 @@ class GitPythonRuntime(CondaRuntime):
 
         Parameters
         ----------
-        python_paths :
+        *python_paths :
             Additional python path(s) for running the source code.
 
         Returns
