@@ -164,7 +164,9 @@ class OCIClientManager:
             config = default_signer()
         self.config = config
         self.ds_client = OCIClientFactory(**config).data_science
-        self.ds_composite_client = oci.data_science.DataScienceClientCompositeOperations(self.ds_client)
+        self.ds_composite_client = (
+            oci.data_science.DataScienceClientCompositeOperations(self.ds_client)
+        )
 
     def default_compartment_id(self):
         """Determines the default compartment OCID
@@ -188,15 +190,17 @@ class OCIClientManager:
             The compartment OCID if found. Otherwise None.
         """
         # Try to get compartment ID from environment variable.')
-        if os.environ.get('NB_SESSION_COMPARTMENT_OCID'):
-            return os.environ.get('NB_SESSION_COMPARTMENT_OCID')
+        if os.environ.get("NB_SESSION_COMPARTMENT_OCID"):
+            return os.environ.get("NB_SESSION_COMPARTMENT_OCID")
         # Try to get compartment ID from OCI config, then RP signer
         # Note: we assume compartment_ids can never be: 0, False, etc.
         oci_config = self.config.get("config")
         signer = self.config.get("signer")
-        return oci_config.get("compartment_id") or oci_config.get("tenancy") or \
-               getattr(signer, "tenancy_id", None)
-
+        return (
+            oci_config.get("compartment_id")
+            or oci_config.get("tenancy")
+            or getattr(signer, "tenancy_id", None)
+        )
 
     def prepare_artifact(self, model_uri: str, properties: Dict) -> str:
         """
